<?php

/*

	Plugin Name: Text Obfuscator
	Plugin URI: http://www.carregs-blog.co.uk/obfuscator
	Description: Text Obfuscator is a simple plugin for replacing words or phrases in your posts' content with different words or phrases.  Initially designed for protecting the innocent by removing names from personal blog posts, it can also be used to correct common spelling errors or expand abbreviations.  The plugin operates on output preserving the content in the database as entered in the post.
	Version: 1.0
	Author: Carreg
	Author URI: http://www.carregs-blog.co.uk/

*/

/*

    Copyright 2008-2010 Carreg (email: carreg@carregs-blog.co.uk)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/

if ( is_admin() ) {
	add_action( 'admin_menu', 'obfuscator_add_pages' );
	add_action( 'admin_init', 'obfuscator_register_settings' );
}

add_filter( 'the_content', 'obfuscator_filter', 10 );
add_filter( 'the_title', 'obfuscator_filter', 10 );
add_filter( 'single_post_title', 'obfuscator_filter', 10 );

function obfuscator_add_pages() {

	add_management_page( 'Text Obfuscator admin', 'Text Obfuscator', 2, 'obfuscator', 'obfuscator_admin_page' );

}

function obfuscator_register_settings() {

	register_setting( 'text-obfuscator', 'obfuscator_replacements', 'obfuscator_sanitize_options' );

}

function obfuscator_sanitize_options( $data ) {

	$sanitizedData = array();
	foreach ( $data AS $replacementPair ) {
		if ( isset( $replacementPair['token'] ) && ( '' != $replacementPair['token'] ) && isset( $replacementPair['value'] ) && ( '' != $replacementPair['value'] ) ) {
			$sanitizedData[] = array( 'token' => $replacementPair['token'],
			                          'value' => $replacementPair['value'] );
		}
	}
	
	return $sanitizedData;

}

function obfuscator_admin_page() {

	$pairModifier = 1;
	if ( isset( $_POST['add_pairs'] ) && is_numeric( $_POST['add_pairs'] ) ) {
		$pairModifier = $_POST['new_pairs'];
	}
	$replacementData = get_option( 'obfuscator_replacements' );

?>
<div class="wrap">
<form id="posts-filter" action="options.php" method="post">
	<?php settings_fields( 'text-obfuscator' ); ?>
	<h2>Text Obfuscator admin</h2>
	<?php if ( isset( $_GET['updated'] ) ) { echo '<div id="message" class="updated fade"><p>Your replacement rules have been updated and applied to all published posts.</p></div>'; } ?>
	<p>Add the terms you want replacing into the boxes in the 'Original text'
	column and the text you want that term replacing with into the boxes in the
	'Replacement' column.  Add one term per line.  To remove a replacer simply
	delete the content from both boxes for that line.</p>
	<p><strong>Note:</strong> Filters are applied to posts when they are fetched from the database and apply to all currently published items as soon as they are saved.</p>
	<table class="form-table">
		<tr valign="top">
			<th scope="column">Original text</th>
			<th scope="column">Replacement</th>
		</tr>
<?php
	$tokenCount = count( $replacementData );
	for ( $i = 0; $i < ($tokenCount + $pairModifier); $i++ ) {
?>
		<tr valign="top">
			<td><input type="text" name="obfuscator_replacements[<?php echo $i; ?>][token]" value="<?php echo htmlentities( $replacementData[$i]['token'] ); ?>" /></td>
			<td><input type="text" name="obfuscator_replacements[<?php echo $i; ?>][value]" value="<?php echo htmlentities( $replacementData[$i]['value'] ); ?>" /></td>
		</tr>
<?php	
	}
?>
	</table>
	<!--<p>Add <input type="text" size="3" value="1" name="new_pairs" /> new pair(s) <input type="submit" name="add_pairs" value="Go" class="button" /></p>-->
	<p class="submit">
		<input type="submit" name="save_pairs" value="Save changes / add blank row" class="button-primary" />
	</p>
</form>
</div>
<?php

}

function obfuscator_filter( $content ) {

	$replacementData = get_option( 'obfuscator_replacements' );
	foreach ( $replacementData AS $replacementItem ) {
		$replacementTokens[] = '/([\W\s]?)'.preg_quote( $replacementItem['token'], '/' ).'([\W\s]+)/i';
		$replacementValues[] = '\\1'.$replacementItem['value'].'\\2';
	}
	return preg_replace( $replacementTokens, $replacementValues, $content );

}

?>